@@ -54,3 +54,7 @@ def main():
 
     for t in threads:
         t.start()
+
+
+if __name__ == '__main__':
+    main()
